Package: seqPattern
Title: Visualising oligonucleotide patterns and motif occurrences
        across a set of sorted sequences
Version: 1.43.0
Date: 08-05-2015
Author: Vanja Haberle <vanja.haberle@gmail.com>
Maintainer: Vanja Haberle <vanja.haberle@gmail.com>
Imports: Biostrings, GenomicRanges, IRanges, KernSmooth, plotrix
Depends: methods, R (>= 2.15.0)
Suggests: BSgenome.Drerio.UCSC.danRer7, CAGEr, RUnit, BiocGenerics,
        BiocStyle
Enhances: parallel
Description: Visualising oligonucleotide patterns and sequence motifs
        occurrences across a large set of sequences centred at a common
        reference point and sorted by a user defined feature.
License: GPL-3
biocViews: Visualization, SequenceMatching
Collate: MotifScanningFunctions.R MotifScanningMethods.R
        PatternOccurrenceFunctions.R PatternOccurrenceMethods.R
        PlottingFunctions.R PlottingMethods.R
git_url: https://git.bioconductor.org/packages/seqPattern
git_branch: devel
git_last_commit: 4b1e21f
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-31
NeedsCompilation: no
Packaged: 2025-11-01 00:09:51 UTC; biocbuild
